/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*global PageControl
 */

var pageControl,
    pageSequence;

function keyEventCB(event) {
    if (event.keyName === "back") {
        if (pageControl.isMainPage() || pageControl.moveBackPage() === false) {
            try {
                tizen.application.getCurrentApplication().exit();
            } catch (ignore) {

            }
        }
    }
}

function setDefaultViews() {
    var defaultErrorMessage = document.querySelector("#errorMessage");

    if (pageControl.movePage(pageSequence[0])) {
        defaultErrorMessage.style.display = "none";
    }
}

function setDefaultVariables() {
    var i;

    pageControl = new PageControl();
    pageSequence = ["pageMain", "pageSecond", "pageThird"];

    for (i = 0; i < pageSequence.length; i++) {
        pageControl.addPage(pageSequence[i]);
    }

    return true;
}

function setDefaultEvents() {
    var wrapBtn,
        btnForward,
        btnBackward,
        pageDiv,
        i;

    document.addEventListener("tizenhwkey", keyEventCB);

    for (i = 0; i < pageSequence.length; i++) {
        pageDiv = document.querySelector("#" + pageSequence[i]).querySelector(".detail");
        wrapBtn = document.createElement("div");
        btnForward = document.createElement("div");
        btnBackward = document.createElement("div");

        wrapBtn.className = "wrapNaviBtn";
        btnForward.appendChild(document.createTextNode("Next >>"));
        btnForward.className = "naviBtn";
        if (i + 1 < pageSequence.length) {
            btnForward.addEventListener("click", pageControl.moveNextPage);
        }
        btnBackward.appendChild(document.createTextNode("<< Prev"));
        btnBackward.className = "naviBtn";
        if (i > 0) {
            btnBackward.addEventListener("click", pageControl.movePrevPage);
        }

        wrapBtn.appendChild(btnBackward);
        wrapBtn.appendChild(btnForward);
        pageDiv.appendChild(wrapBtn);
    }

    return true;
}

function init() {
    if (setDefaultVariables() && setDefaultEvents()) {
        console.log("App: init");
        setDefaultViews();
    } else {
        console.error("App: init failed.");
    }
}

window.onload = init;